@@ -22,7 +22,8 @@
 #include <QtGui/QDialog>
 
 class QString;
-class ButtonSelector;
+class ThemePicker;
+class ThemeSchedulerSettings;
 
 class ThemeSelector : public QDialog
 {
@@ -37,16 +38,12 @@ signals:
 private slots:
     void saveTheme();
     void loadFromFile();
-
-protected:
-    virtual void setVisible(bool visible);
+    void openScheduler();
+    void disableScheduler();
 
 private:
-    void loadThemes();
-    void getThemeDetails(QString filename, QString& name, QString& id);
-    bool confirmCopy(QString const& name);
-    ButtonSelector* selector_;
-    QString theme_;
+    ThemePicker* selector_;
+    ThemeSchedulerSettings* themeScheduler_;
 };
 
 
